@@ -775,7 +775,7 @@ class SchemaView(object):
         has all properties materialized.
 
         This makes use of schema slots, such as attributes, slot_usage. It also uses ancestor relationships
-        to infer missing values
+        to infer missing values, for inheritable slots
 
         :param slot_name: slot to be queries
         :param class_name: class used as context
@@ -786,8 +786,11 @@ class SchemaView(object):
         cls = self.get_class(class_name, imports)
         islot = None
         if slot is not None:
+            # case 1: there is an explicit declaration of the slot
             islot = deepcopy(slot)
         else:
+            # case 2: no independent slot definition, declared as an attribute
+            # (can be attribute of the class, or an ancestor)
             for an in self.class_ancestors(class_name):
                 a = self.get_class(an, imports)
                 if slot_name in a.attributes:
@@ -800,11 +803,16 @@ class SchemaView(object):
             'maximum_value': lambda x, y: min(x, y),
             'minimum_value': lambda x, y: max(x, y),
         }
-        for metaslot_name in SlotDefinition._inherited_slots:
+        # iterate through all metaslots, and potentially populate metaslot value for induced slot
+        for metaslot_name in self._metaslots_for_slot():
             # inheritance of slots; priority order
             #   slot-level assignment < ancestor slot_usage < self slot_usage
             v = getattr(islot, metaslot_name, None)
-            for an in reversed(self.class_ancestors(class_name)):
+            if metaslot_name in SlotDefinition._inherited_slots:
+                propagated_from = self.class_ancestors(class_name, reflexive=True, mixins=True)
+            else:
+                propagated_from = [class_name]
+            for an in reversed(propagated_from):
                 islot.owner = an
                 a = self.get_class(an, imports)
                 anc_slot_usage = a.slot_usage.get(slot_name, {})
@@ -828,6 +836,11 @@ class SchemaView(object):
             slot.inlined = True
         return deepcopy(islot)
 
+    @lru_cache()
+    def _metaslots_for_slot(self):
+        fake_slot = SlotDefinition('__FAKE')
+        return vars(fake_slot).keys()
+
     @lru_cache()
     def class_induced_slots(self, class_name: CLASS_NAME = None, imports=True) -> List[SlotDefinition]:
         """
